ViewError

Enum ViewError 

pub enum ViewError {
Show 13 variants BcsError(Error), IoError(Error), ArithmeticError(ArithmeticError), TryLockError(Vec<u8>), TokioJoinError(JoinError), StoreError { backend: &'static str, error: Box<dyn Error + Sync + Send>, must_reload_view: bool, }, KeyTooLong, NotFound(String), InconsistentEntries, MissingEntries(String), PostLoadValuesError, HasPendingChanges, MalformedContent(&'static str),
}
Main error type for the crate.

Variants



BcsError(Error)

BCS serialization error.



IoError(Error)

Input output error.



ArithmeticError(ArithmeticError)

Arithmetic error



TryLockError(Vec<u8>)

Failed to lock a reentrant collection entry since it is currently being accessed



TokioJoinError(JoinError)

Tokio errors can happen while joining.



StoreError

Errors within the context can occur and are presented as ViewError.

Fields

backend: &'static str

The name of the backend that produced the error

error: Box<dyn Error + Sync + Send>

The inner error

must_reload_view: bool

Whether this error may have left storage in an undetermined state, so the view must be reloaded before being used again.



KeyTooLong

The key must not be too long



NotFound(String)

The entry does not exist in memory



InconsistentEntries

The database is corrupt: Entries don’t have the expected hash.



MissingEntries(String)

The database is corrupt: Some entries are missing



PostLoadValuesError

The values are incoherent.



HasPendingChanges

The operation requires the view to have no pending in-memory changes.



MalformedContent(&'static str)

The canonical byte stream is malformed.

Implementations

Source

impl ViewError

pub fn must_reload_view(&self) -> bool

Returns true if this error may have left storage in an undetermined state, so the view must be reloaded before being used again.