pub struct KeyValueStore { /* private fields */ }Expand description
A type to interface with the key value storage provided to applications.
Implementations
Sourceimpl KeyValueStore
impl KeyValueStore
Sourcepub fn mock() -> Self
pub fn mock() -> Self
Returns a new KeyValueStore that just keeps the storage contents in memory.
Sourcepub fn to_mut(&self) -> Self
pub fn to_mut(&self) -> Self
Returns a mocked KeyValueStore that shares the memory storage with this instance but
allows write operations.